@@ -31,15 +31,15 @@ __all__ = (
     'SassError', 'SassFunction', 'SassList', 'SassMap', 'SassNumber',
     'SassWarning', 'and_join', 'compile', 'libsass_version',
 )
-__version__ = '0.13.2'
+__version__ = '0.14.3'
 libsass_version = _sass.libsass_version
 
 
-#: (:class:`collections.Mapping`) The dictionary of output styles.
+#: (:class:`collections.abc.Mapping`) The dictionary of output styles.
 #: Keys are output name strings, and values are flag integers.
 OUTPUT_STYLES = _sass.OUTPUT_STYLES
 
-#: (:class:`collections.Mapping`) The dictionary of source comments styles.
+#: (:class:`collections.abc.Mapping`) The dictionary of source comments styles.
 #: Keys are mode names, and values are corresponding flag integers.
 #:
 #: .. versionadded:: 0.4.0
@@ -47,8 +47,8 @@ OUTPUT_STYLES = _sass.OUTPUT_STYLES
 #: .. deprecated:: 0.6.0
 SOURCE_COMMENTS = {'none': 0, 'line_numbers': 1, 'default': 1, 'map': 2}
 
-#: (:class:`collections.Set`) The set of keywords :func:`compile()` can take.
-MODES = set(['string', 'filename', 'dirname'])
+#: (:class:`frozenset`) The set of keywords :func:`compile()` can take.
+MODES = frozenset(('string', 'filename', 'dirname'))
 
 
 def to_native_s(s):
@@ -83,9 +83,9 @@ class SassFunction(object):
     :param name: the function name
     :type name: :class:`str`
     :param arguments: the argument names
-    :type arguments: :class:`collections.Sequence`
+    :type arguments: :class:`collections.abc.Sequence`
     :param callable_: the actual function to be called
-    :type callable_: :class:`collections.Callable`
+    :type callable_: :class:`collections.abc.Callable`
 
     .. versionadded:: 0.7.0
 
@@ -267,11 +267,11 @@ def compile(**kwargs):
     """There are three modes of parameters :func:`compile()` can take:
     ``string``, ``filename``, and ``dirname``.
 
-    The ``string`` parameter is the most basic way to compile SASS.
-    It simply takes a string of SASS code, and then returns a compiled
+    The ``string`` parameter is the most basic way to compile Sass.
+    It simply takes a string of Sass code, and then returns a compiled
     CSS string.
 
-    :param string: SASS source code to compile.  it's exclusive to
+    :param string: Sass source code to compile.  it's exclusive to
                    ``filename`` and ``dirname`` parameters
     :type string: :class:`str`
     :param output_style: an optional coding style of the compiled result.
@@ -282,32 +282,32 @@ def compile(**kwargs):
                             :const:`False` by default
     :type source_comments: :class:`bool`
     :param include_paths: an optional list of paths to find ``@import``\ ed
-                          SASS/CSS source files
-    :type include_paths: :class:`collections.Sequence`
+                          Sass/CSS source files
+    :type include_paths: :class:`collections.abc.Sequence`
     :param precision: optional precision for numbers. :const:`5` by default.
     :type precision: :class:`int`
     :param custom_functions: optional mapping of custom functions.
                              see also below `custom functions
-                             <custom-functions>`_ description
-    :type custom_functions: :class:`collections.Set`,
-                            :class:`collections.Sequence`,
-                            :class:`collections.Mapping`
-    :param indented: optional declaration that the string is SASS, not SCSS
+                             <custom-functions_>`_ description
+    :type custom_functions: :class:`set`,
+                            :class:`collections.abc.Sequence`,
+                            :class:`collections.abc.Mapping`
+    :param indented: optional declaration that the string is Sass, not SCSS
                      formatted. :const:`False` by default
     :type indented: :class:`bool`
     :returns: the compiled CSS string
     :param importers: optional callback functions.
                      see also below `importer callbacks
-                     <importer-callbacks>`_ description
-    :type importers: :class:`collections.Callable`
+                     <importer-callbacks_>`_ description
+    :type importers: :class:`collections.abc.Callable`
     :rtype: :class:`str`
     :raises sass.CompileError: when it fails for any reason
-                               (for example the given SASS has broken syntax)
+                               (for example the given Sass has broken syntax)
 
     The ``filename`` is the most commonly used way.  It takes a string of
-    SASS filename, and then returns a compiled CSS string.
+    Sass filename, and then returns a compiled CSS string.
 
-    :param filename: the filename of SASS source code to compile.
+    :param filename: the filename of Sass source code to compile.
                      it's exclusive to ``string`` and ``dirname`` parameters
     :type filename: :class:`str`
     :param output_style: an optional coding style of the compiled result.
@@ -322,31 +322,31 @@ def compile(**kwargs):
                                 using source maps.  :const:`None` by default.
     :type source_map_filename: :class:`str`
     :param include_paths: an optional list of paths to find ``@import``\ ed
-                          SASS/CSS source files
-    :type include_paths: :class:`collections.Sequence`
+                          Sass/CSS source files
+    :type include_paths: :class:`collections.abc.Sequence`
     :param precision: optional precision for numbers. :const:`5` by default.
     :type precision: :class:`int`
     :param custom_functions: optional mapping of custom functions.
                              see also below `custom functions
-                             <custom-functions>`_ description
-    :type custom_functions: :class:`collections.Set`,
-                            :class:`collections.Sequence`,
-                            :class:`collections.Mapping`
+                             <custom-functions_>`_ description
+    :type custom_functions: :class:`set`,
+                            :class:`collections.abc.Sequence`,
+                            :class:`collections.abc.Mapping`
     :param importers: optional callback functions.
                      see also below `importer callbacks
-                     <importer-callbacks>`_ description
-    :type importers: :class:`collections.Callable`
+                     <importer-callbacks_>`_ description
+    :type importers: :class:`collections.abc.Callable`
     :returns: the compiled CSS string, or a pair of the compiled CSS string
               and the source map string if ``source_map_filename`` is set
     :rtype: :class:`str`, :class:`tuple`
     :raises sass.CompileError: when it fails for any reason
-                               (for example the given SASS has broken syntax)
+                               (for example the given Sass has broken syntax)
     :raises exceptions.IOError: when the ``filename`` doesn't exist or
                                 cannot be read
 
     The ``dirname`` is useful for automation.  It takes a pair of paths.
     The first of the ``dirname`` pair refers the source directory, contains
-    several SASS source files to compiled.  SASS source files can be nested
+    several Sass source files to compiled.  Sass source files can be nested
     in directories.  The second of the pair refers the output directory
     that compiled CSS files would be saved.  Directory tree structure of
     the source directory will be maintained in the output directory as well.
@@ -364,24 +364,24 @@ def compile(**kwargs):
                             :const:`False` by default
     :type source_comments: :class:`bool`
     :param include_paths: an optional list of paths to find ``@import``\ ed
-                          SASS/CSS source files
-    :type include_paths: :class:`collections.Sequence`
+                          Sass/CSS source files
+    :type include_paths: :class:`collections.abc.Sequence`
     :param precision: optional precision for numbers. :const:`5` by default.
     :type precision: :class:`int`
     :param custom_functions: optional mapping of custom functions.
                              see also below `custom functions
-                             <custom-functions>`_ description
-    :type custom_functions: :class:`collections.Set`,
-                            :class:`collections.Sequence`,
-                            :class:`collections.Mapping`
+                             <custom-functions_>`_ description
+    :type custom_functions: :class:`set`,
+                            :class:`collections.abc.Sequence`,
+                            :class:`collections.abc.Mapping`
     :raises sass.CompileError: when it fails for any reason
-                               (for example the given SASS has broken syntax)
+                               (for example the given Sass has broken syntax)
 
     .. _custom-functions:
 
     The ``custom_functions`` parameter can take three types of forms:
 
-    :class:`~collections.Set`/:class:`~collections.Sequence` of \
+    :class:`~set`/:class:`~collections.abc.Sequence` of \
     :class:`SassFunction`\ s
        It is the most general form.  Although pretty verbose, it can take
        any kind of callables like type objects, unnamed functions,
@@ -397,7 +397,7 @@ def compile(**kwargs):
               }
           )
 
-    :class:`~collections.Mapping` of names to functions
+    :class:`~collections.abc.Mapping` of names to functions
        Less general, but easier-to-use form.  Although it's not it can take
        any kind of callables, it can take any kind of *functions* defined
        using :keyword:`def`/:keyword:`lambda` syntax.
@@ -414,7 +414,7 @@ def compile(**kwargs):
               }
           )
 
-    :class:`~collections.Set`/:class:`~collections.Sequence` of \
+    :class:`~set`/:class:`~collections.abc.Sequence` of \
     named functions
        Not general, but the easiest-to-use form for *named* functions.
        It can take only named functions, defined using :keyword:`def`.
@@ -647,7 +647,7 @@ def and_join(strings):
     'Korea, Japan, China, and Taiwan'
 
     :param strings: a list of words to join
-    :type string: :class:`collections.Sequence`
+    :type string: :class:`collections.abc.Sequence`
     :returns: a joined string
     :rtype: :class:`str`, :class:`basestring`
 
@@ -702,12 +702,15 @@ SASS_SEPARATOR_SPACE = collections.namedtuple('SASS_SEPARATOR_SPACE', ())()
 SEPARATORS = frozenset((SASS_SEPARATOR_COMMA, SASS_SEPARATOR_SPACE))
 
 
-class SassList(collections.namedtuple('SassList', ('items', 'separator'))):
+class SassList(collections.namedtuple(
+        'SassList', ('items', 'separator', 'bracketed'),
+)):
 
-    def __new__(cls, items, separator):
+    def __new__(cls, items, separator, bracketed=False):
         items = tuple(items)
-        assert separator in SEPARATORS
-        return super(SassList, cls).__new__(cls, items, separator)
+        assert separator in SEPARATORS, separator
+        assert isinstance(bracketed, bool), bracketed
+        return super(SassList, cls).__new__(cls, items, separator, bracketed)
 
 
 class SassError(collections.namedtuple('SassError', ('msg',))):
