@@ -618,8 +618,8 @@ class ManifestTestCase(BaseTestCase):
                     'names': [],
                     'mappings': (
                         ';AAKA,AAAA,IAAI,CAAC;EAHH,gBAAgB,EAAE,KAAK,GAQxB;'
-                        'EALD,AAEE,IAFE,CAEF,CAAC,CAAC;IACA,IAAI,EAAE,0BAA0B,'
-                        'GACjC'
+                        'EALD,AAEE,IAFE,CAEF,CAAC,CAAC;IACA,IAAI,EAAE,sBAAsB,'
+                        'GAC7B'
                     ),
                 },
                 os.path.join(d, 'css', 'd.scss.css.map')
@@ -921,16 +921,12 @@ class SassTypesTest(unittest.TestCase):
         assert type(color.a) is float, type(color.a)
 
     def test_sass_list_no_conversion(self):
-        lst = sass.SassList(
-            ('foo', 'bar'), sass.SASS_SEPARATOR_COMMA,
-        )
+        lst = sass.SassList(('foo', 'bar'), sass.SASS_SEPARATOR_COMMA)
         assert type(lst.items) is tuple, type(lst.items)
         assert lst.separator is sass.SASS_SEPARATOR_COMMA, lst.separator
 
     def test_sass_list_conversion(self):
-        lst = sass.SassList(
-            ['foo', 'bar'], sass.SASS_SEPARATOR_SPACE,
-        )
+        lst = sass.SassList(['foo', 'bar'], sass.SASS_SEPARATOR_SPACE)
         assert type(lst.items) is tuple, type(lst.items)
         assert lst.separator is sass.SASS_SEPARATOR_SPACE, lst.separator
 
@@ -1004,6 +1000,12 @@ def returns_space_list():
     return sass.SassList(('medium', 'none'), sass.SASS_SEPARATOR_SPACE)
 
 
+def returns_bracketed_list():
+    return sass.SassList(
+        ('hello', 'ohai'), sass.SASS_SEPARATOR_SPACE, bracketed=True,
+    )
+
+
 def returns_py_dict():
     return {'foo': 'bar'}
 
@@ -1035,6 +1037,7 @@ custom_functions = frozenset([
     sass.SassFunction('returns_color', (), returns_color),
     sass.SassFunction('returns_comma_list', (), returns_comma_list),
     sass.SassFunction('returns_space_list', (), returns_space_list),
+    sass.SassFunction('returns_bracketed_list', (), returns_bracketed_list),
     sass.SassFunction('returns_py_dict', (), returns_py_dict),
     sass.SassFunction('returns_map', (), returns_map),
     sass.SassFunction('identity', ('$x',), identity),
@@ -1054,6 +1057,7 @@ custom_function_map = {
     'returns_color': returns_color,
     'returns_comma_list': returns_comma_list,
     'returns_space_list': returns_space_list,
+    'returns_bracketed_list': returns_bracketed_list,
     'returns_py_dict': returns_py_dict,
     'returns_map': returns_map,
     'identity': identity,
@@ -1073,6 +1077,7 @@ custom_function_set = frozenset([
     returns_color,
     returns_comma_list,
     returns_space_list,
+    returns_bracketed_list,
     returns_py_dict,
     returns_map,
     identity,
@@ -1123,11 +1128,9 @@ class CustomFunctionsTest(unittest.TestCase):
                 r'^Error: error in C function raises: \n'
                 r'       Traceback \(most recent call last\):\n'
                 r'.+'
-                r'AssertionError: foo\n\n\n'
-                r'       Backtrace:\n'
-                r'       \tstdin:1, in function `raises`\n'
-                r'       \tstdin:1\n'
-                r'        on line 1 of stdin\n'
+                r'AssertionError: foo\n'
+                r'        on line 1 of stdin, in function `raises`\n'
+                r'        from line 1 of stdin\n'
                 r'>> a { content: raises\(\); }\n'
                 r'   -------------\^\n$'
         )):
@@ -1136,11 +1139,9 @@ class CustomFunctionsTest(unittest.TestCase):
     def test_warning(self):
         with assert_raises_compile_error(
                 'Error: warning in C function returns_warning: '
-                'This is a warning\n\n'
-                '       Backtrace:\n'
-                '       \tstdin:1, in function `returns_warning`\n'
-                '       \tstdin:1\n'
-                '        on line 1 of stdin\n'
+                'This is a warning\n'
+                '        on line 1 of stdin, in function `returns_warning`\n'
+                '        from line 1 of stdin\n'
                 '>> a { content: returns_warning(); }\n'
                 '   -------------^\n'
         ):
@@ -1149,11 +1150,9 @@ class CustomFunctionsTest(unittest.TestCase):
     def test_error(self):
         with assert_raises_compile_error(
                 'Error: error in C function returns_error: '
-                'This is an error\n\n'
-                '       Backtrace:\n'
-                '       \tstdin:1, in function `returns_error`\n'
-                '       \tstdin:1\n'
-                '        on line 1 of stdin\n'
+                'This is an error\n'
+                '        on line 1 of stdin, in function `returns_error`\n'
+                '        from line 1 of stdin\n'
                 '>> a { content: returns_error(); }\n'
                 '   -------------^\n'
         ):
@@ -1173,11 +1172,9 @@ class CustomFunctionsTest(unittest.TestCase):
                 '       - dict\n'
                 '       - SassMap\n'
                 '       - SassWarning\n'
-                '       - SassError\n\n\n'
-                '       Backtrace:\n'
-                '       \tstdin:1, in function `returns_unknown`\n'
-                '       \tstdin:1\n'
-                '        on line 1 of stdin\n'
+                '       - SassError\n'
+                '        on line 1 of stdin, in function `returns_unknown`\n'
+                '        from line 1 of stdin\n'
                 '>> a { content: returns_unknown(); }\n'
                 '   -------------^\n'
         ):
@@ -1237,6 +1234,12 @@ class CustomFunctionsTest(unittest.TestCase):
             'a{border-right:medium none}\n',
         )
 
+    def test_bracketed_list(self):
+        self.assertEqual(
+            compile_with_func('a { content: returns_bracketed_list(); }'),
+            'a{content:[hello ohai]}\n'
+        )
+
     def test_py_dict(self):
         self.assertEqual(
             compile_with_func(
@@ -1307,6 +1310,14 @@ class CustomFunctionsTest(unittest.TestCase):
             'a{border-right:medium none}\n',
         )
 
+    def test_identity_bracketed_list(self):
+        self.assertEqual(
+            compile_with_func(
+                'a { content: identity(returns_bracketed_list()); }',
+            ),
+            'a{content:[hello ohai]}\n',
+        )
+
     def test_identity_py_dict(self):
         self.assertEqual(
             compile_with_func(
